@@ -31,6 +31,7 @@ from datetime import datetime
 from email import message_from_bytes, policy
 from email.utils import make_msgid, unquote
 from math import floor
+from string import printable
 from traceback import print_exc
 
 from django.conf import settings
@@ -131,7 +132,10 @@ class DbImporter(object):
     def _get_date(self, message, header, report_name):
         try:
             date = message.get(header)
-        except (TypeError, ValueError) as e:
+            if date:
+                assert all(char in printable for char in date)
+                assert date.datetime is not None
+        except (AssertionError, TypeError, ValueError) as e:
             if self.verbose:
                 self.stderr.write(
                     "Can't get {} header in message {}{}: {}.".format(
